@@ -30,4 +30,8 @@ class ConnectionPoolClass():
   def close(self, wait):
     for con in self.connections:
       con.close(wait=wait)
-    self.connections = ()
\ No newline at end of file
+    self.connections = ()
+
+  def healthCheck(self):
+    for con in self.connections:
+      con.healthCheck()
